@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_COMMANDS_ADDUSERIDCOMMAND_H__
-#define __KLEOPATRA_COMMANDS_ADDUSERIDCOMMAND_H__
+#pragma once
 
 #include <commands/command.h>
 
@@ -57,4 +56,3 @@ private:
 }
 }
 
-#endif // __KLEOPATRA_COMMANDS_ADDUSERIDCOMMAND_H__
