@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_COMMANDS_CERTIFYCERTIFICATECOMMAND_H__
-#define __KLEOPATRA_COMMANDS_CERTIFYCERTIFICATECOMMAND_H__
+#pragma once
 
 #include <commands/command.h>
 
@@ -38,14 +37,6 @@ public:
         return OnlyOneKey | MustBeOpenPGP;
     }
 
-    void setCertificationExportable(bool on);
-    void setCertificationRevocable(bool on);
-
-    void setCertifyingKey(const GpgME::Key &key);
-
-    void setUserID(const GpgME::UserID &uid);
-    void setUserIDs(const std::vector<GpgME::UserID> &uids);
-
 private:
     void doStart() override;
     void doCancel() override;
@@ -62,4 +53,3 @@ private:
 }
 }
 
-#endif // __KLEOPATRA_COMMANDS_SIGNCERTIFICATECOMMAND_H__
