@@ -3,6 +3,8 @@
 
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2008 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2021 g10 Code GmbH
+    SPDX-FileContributor: Ingo Klöcker <dev@ingo-kloecker.de>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,24 +12,22 @@
 #include <config-kleopatra.h>
 
 #include "changeexpirycommand.h"
-
 #include "command_p.h"
 
-#include <dialogs/expirydialog.h>
+#include "dialogs/expirydialog.h"
 
 #include <Libkleo/Formatting>
 
+#include <KLocalizedString>
+
 #include <QGpgME/Protocol>
 #include <QGpgME/ChangeExpiryJob>
 
-#include <gpgme++/key.h>
-
-#include <KLocalizedString>
-#include "kleopatra_debug.h"
-
 #include <QDateTime>
 
-#include <QDebug>
+#include <gpgme++/key.h>
+
+#include "kleopatra_debug.h"
 
 #include <gpgme++/gpgmepp_version.h>
 #if GPGMEPP_VERSION >= 0x10E01 // 1.14.1
@@ -40,6 +40,32 @@ using namespace Kleo::Dialogs;
 using namespace GpgME;
 using namespace QGpgME;
 
+namespace
+{
+#ifdef QGPGME_SUPPORTS_CHANGING_EXPIRATION_OF_COMPLETE_KEY
+bool allNotRevokedSubkeysHaveSameExpirationAsPrimaryKey(const Key &key)
+{
+    Q_ASSERT(!key.isNull() && key.numSubkeys() > 0);
+    const auto subkeys = key.subkeys();
+    const auto primaryKey = subkeys[0];
+    if (primaryKey.neverExpires()) {
+        return std::all_of(std::begin(subkeys), std::end(subkeys), [] (const auto &subkey) {
+            // revoked subkeys are ignored by gpg --quick-set-expire when updating the expiration of all subkeys
+            return subkey.isRevoked() || subkey.neverExpires();
+        });
+    }
+
+    const auto primaryExpiration = primaryKey.expirationTime();
+    return std::all_of(std::begin(subkeys), std::end(subkeys), [primaryExpiration] (const auto &subkey) {
+        // revoked subkeys are ignored by gpg --quick-set-expire when updating the expiration of all subkeys;
+        // check if expiration of subkey is (more or less) the same as the expiration of the primary key
+        return subkey.isRevoked() ||
+            (primaryExpiration - 10 <= subkey.expirationTime() && subkey.expirationTime() <= primaryExpiration + 10);
+    });
+}
+#endif
+}
+
 class ChangeExpiryCommand::Private : public Command::Private
 {
     friend class ::Kleo::Commands::ChangeExpiryCommand;
@@ -49,9 +75,7 @@ class ChangeExpiryCommand::Private : public Command::Private
     }
 public:
     explicit Private(ChangeExpiryCommand *qq, KeyListController *c);
-    ~Private();
-
-    void init();
+    ~Private() override;
 
 private:
     void slotDialogAccepted();
@@ -59,7 +83,7 @@ private:
     void slotResult(const Error &err);
 
 private:
-    void ensureDialogCreated();
+    void ensureDialogCreated(ExpiryDialog::Mode mode);
     void createJob();
     void showErrorDialog(const Error &error);
     void showSuccessDialog();
@@ -84,102 +108,37 @@ const ChangeExpiryCommand::Private *ChangeExpiryCommand::d_func() const
 #define q q_func()
 
 ChangeExpiryCommand::Private::Private(ChangeExpiryCommand *qq, KeyListController *c)
-    : Command::Private(qq, c),
-      key(),
-      dialog(),
-      job()
+    : Command::Private{qq, c}
 {
-
 }
 
-ChangeExpiryCommand::Private::~Private()
-{
-    qCDebug(KLEOPATRA_LOG);
-}
-
-ChangeExpiryCommand::ChangeExpiryCommand(KeyListController *c)
-    : Command(new Private(this, c))
-{
-    d->init();
-}
-
-ChangeExpiryCommand::ChangeExpiryCommand(QAbstractItemView *v, KeyListController *c)
-    : Command(v, new Private(this, c))
-{
-    d->init();
-}
-
-ChangeExpiryCommand::ChangeExpiryCommand(const GpgME::Key &key)
-    : Command(key, new Private(this, nullptr))
-{
-    d->init();
-}
-
-void ChangeExpiryCommand::Private::init()
-{
-
-}
-
-ChangeExpiryCommand::~ChangeExpiryCommand()
-{
-    qCDebug(KLEOPATRA_LOG);
-}
-
-void ChangeExpiryCommand::setSubkey(const GpgME::Subkey &subkey)
-{
-    d->subkey = subkey;
-}
-
-void ChangeExpiryCommand::doStart()
-{
-    const std::vector<Key> keys = d->keys();
-    if (keys.size() != 1 ||
-            keys.front().protocol() != GpgME::OpenPGP ||
-            !keys.front().hasSecret() ||
-            keys.front().subkey(0).isNull()) {
-        d->finished();
-        return;
-    }
-
-    d->key = keys.front();
-
-    if (!d->subkey.isNull() &&
-            d->subkey.parent().primaryFingerprint() != d->key.primaryFingerprint()) {
-        qDebug() << "Invalid subkey" << d->subkey.fingerprint()
-                 << ": Not a subkey of key" << d->key.primaryFingerprint();
-        d->finished();
-        return;
-    }
-
-    const Subkey subkey = !d->subkey.isNull() ? d->subkey : d->key.subkey(0);
-
-    d->ensureDialogCreated();
-    Q_ASSERT(d->dialog);
-    d->dialog->setDateOfExpiry(subkey.neverExpires() ? QDate() :
-                               QDateTime::fromSecsSinceEpoch(subkey.expirationTime()).date());
-    d->dialog->show();
-
-}
+ChangeExpiryCommand::Private::~Private() = default;
 
 void ChangeExpiryCommand::Private::slotDialogAccepted()
 {
     Q_ASSERT(dialog);
 
-    static const QTime END_OF_DAY(23, 59, 59);
+    static const QTime END_OF_DAY{23, 59, 59};
 
-    const QDateTime expiry(dialog->dateOfExpiry(), END_OF_DAY);
+    const QDateTime expiry{dialog->dateOfExpiry(), END_OF_DAY};
 
     qCDebug(KLEOPATRA_LOG) << "expiry" << expiry;
 
     createJob();
     Q_ASSERT(job);
 
+#ifdef QGPGME_SUPPORTS_CHANGING_EXPIRATION_OF_COMPLETE_KEY
+    if (subkey.isNull() && dialog->updateExpirationOfAllSubkeys()) {
+        job->setOptions(ChangeExpiryJob::UpdateAllSubkeys);
+    }
+#endif
+
+#ifdef CHANGEEXPIRYJOB_SUPPORTS_SUBKEYS
     std::vector<Subkey> subkeys;
-    if (!subkey.isNull()) {
+    if (!subkey.isNull() && subkey.keyID() != key.keyID()) { // ignore the primary subkey
         subkeys.push_back(subkey);
     }
 
-#ifdef CHANGEEXPIRYJOB_SUPPORTS_SUBKEYS
     if (const Error err = job->start(key, expiry, subkeys)) {
 #else
     if (const Error err = job->start(key, expiry)) {
@@ -207,21 +166,13 @@ void ChangeExpiryCommand::Private::slotResult(const Error &err)
     finished();
 }
 
-void ChangeExpiryCommand::doCancel()
-{
-    qCDebug(KLEOPATRA_LOG);
-    if (d->job) {
-        d->job->slotCancel();
-    }
-}
-
-void ChangeExpiryCommand::Private::ensureDialogCreated()
+void ChangeExpiryCommand::Private::ensureDialogCreated(ExpiryDialog::Mode mode)
 {
     if (dialog) {
         return;
     }
 
-    dialog = new ExpiryDialog;
+    dialog = new ExpiryDialog{mode};
     applyWindowID(dialog);
     dialog->setAttribute(Qt::WA_DeleteOnClose);
 
@@ -245,8 +196,8 @@ void ChangeExpiryCommand::Private::createJob()
 
     connect(j, &Job::progress,
             q, &Command::progress);
-    connect(j, SIGNAL(result(GpgME::Error)),
-            q, SLOT(slotResult(GpgME::Error)));
+    connect(j, &ChangeExpiryJob::result,
+            q, [this] (const auto &err) { slotResult(err); });
 
     job = j;
 }
@@ -266,6 +217,79 @@ void ChangeExpiryCommand::Private::showSuccessDialog()
                 i18n("Expiry Date Change Succeeded"));
 }
 
+ChangeExpiryCommand::ChangeExpiryCommand(KeyListController *c)
+    : Command{new Private{this, c}}
+{
+}
+
+ChangeExpiryCommand::ChangeExpiryCommand(QAbstractItemView *v, KeyListController *c)
+    : Command{v, new Private{this, c}}
+{
+}
+
+ChangeExpiryCommand::ChangeExpiryCommand(const GpgME::Key &key)
+    : Command{key, new Private{this, nullptr}}
+{
+}
+
+ChangeExpiryCommand::~ChangeExpiryCommand() = default;
+
+void ChangeExpiryCommand::setSubkey(const GpgME::Subkey &subkey)
+{
+    d->subkey = subkey;
+}
+
+void ChangeExpiryCommand::doStart()
+{
+    const std::vector<Key> keys = d->keys();
+    if (keys.size() != 1 ||
+            keys.front().protocol() != GpgME::OpenPGP ||
+            !keys.front().hasSecret() ||
+            keys.front().subkey(0).isNull()) {
+        d->finished();
+        return;
+    }
+
+    d->key = keys.front();
+
+    if (!d->subkey.isNull() &&
+            d->subkey.parent().primaryFingerprint() != d->key.primaryFingerprint()) {
+        qDebug() << "Invalid subkey" << d->subkey.fingerprint()
+                 << ": Not a subkey of key" << d->key.primaryFingerprint();
+        d->finished();
+        return;
+    }
+
+    ExpiryDialog::Mode mode;
+    if (!d->subkey.isNull()) {
+        mode = ExpiryDialog::Mode::UpdateIndividualSubkey;
+    } else if (d->key.numSubkeys() == 1) {
+        mode = ExpiryDialog::Mode::UpdateCertificateWithoutSubkeys;
+    } else {
+        mode = ExpiryDialog::Mode::UpdateCertificateWithSubkeys;
+    }
+    d->ensureDialogCreated(mode);
+    Q_ASSERT(d->dialog);
+    const Subkey subkey = !d->subkey.isNull() ? d->subkey : d->key.subkey(0);
+    d->dialog->setDateOfExpiry(subkey.neverExpires() ? QDate() :
+                               QDateTime::fromSecsSinceEpoch(subkey.expirationTime()).date());
+#ifdef QGPGME_SUPPORTS_CHANGING_EXPIRATION_OF_COMPLETE_KEY
+    if (mode == ExpiryDialog::Mode::UpdateCertificateWithSubkeys) {
+        d->dialog->setUpdateExpirationOfAllSubkeys(allNotRevokedSubkeysHaveSameExpirationAsPrimaryKey(d->key));
+    }
+#endif
+
+    d->dialog->show();
+
+}
+
+void ChangeExpiryCommand::doCancel()
+{
+    if (d->job) {
+        d->job->slotCancel();
+    }
+}
+
 #undef d
 #undef q
 
