@@ -8,8 +8,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_COMMANDS_CREATECSRFORCARDKEYCOMMAND_H__
-#define __KLEOPATRA_COMMANDS_CREATECSRFORCARDKEYCOMMAND_H__
+#pragma once
 
 #include "cardcommand.h"
 
@@ -41,4 +40,3 @@ private:
 } // namespace Commands
 } // namespace Kleo
 
-#endif // __KLEOPATRA_COMMANDS_CREATECSRFORCARDKEYCOMMAND_H__
