@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_COMMMANDS_DUMPCRLCACHECOMMAND_H__
-#define __KLEOPATRA_COMMMANDS_DUMPCRLCACHECOMMAND_H__
+#pragma once
 
 #include <commands/command.h>
 
@@ -43,4 +42,3 @@ private:
 }
 }
 
-#endif // __KLEOPATRA_COMMMANDS_DUMPCRLCACHECOMMAND_H__
