@@ -8,8 +8,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_COMMMANDS_EXPORTPAPERKEYCOMMAND_H__
-#define __KLEOPATRA_COMMMANDS_EXPORTPAPERKEYCOMMAND_H__
+#pragma once
 
 #include <commands/gnupgprocesscommand.h>
 
@@ -56,4 +55,3 @@ private:
 }
 }
 
-#endif // __KLEOPATRA_COMMMANDS_EXPORTPAPERKEYCOMMAND_H__
