@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_IMPORTCERTIFICATESCOMMAND_H__
-#define __KLEOPATRA_IMPORTCERTIFICATESCOMMAND_H__
+#pragma once
 
 #include "command.h"
 
@@ -41,5 +40,4 @@ protected:
 };
 }
 
-#endif // __KLEOPATRA_IMPORTCERTIFICATESCOMMAND_H__
 
