@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_IMPORTCERTIFICATESCOMMAND_P_H__
-#define __KLEOPATRA_IMPORTCERTIFICATESCOMMAND_P_H__
+#pragma once
 
 #include "command_p.h"
 #include "importcertificatescommand.h"
@@ -42,7 +41,7 @@ class Kleo::ImportCertificatesCommand::Private : public Command::Private
     }
 public:
     explicit Private(ImportCertificatesCommand *qq, KeyListController *c);
-    ~Private();
+    ~Private() override;
 
     void setWaitForMoreJobs(bool waiting);
 
@@ -65,12 +64,11 @@ public:
                      const std::vector<GpgME::Key> &keys,
                      const QString &, const GpgME::Error&);
 private:
-    void handleExternalCMSImports();
+    void processResults();
     void tryToFinish();
 
 private:
-    bool waitForMoreJobs;
-    bool containedExternalCMSCerts;
+    bool waitForMoreJobs = false;
     std::vector<GpgME::Protocol> nonWorkingProtocols;
     std::map<QObject *, QString> idsByJob;
     std::vector<QGpgME::AbstractImportJob *> jobs;
@@ -90,5 +88,4 @@ inline const Kleo::ImportCertificatesCommand::Private *Kleo::ImportCertificatesC
 inline Kleo::ImportCertificatesCommand::ImportCertificatesCommand(Private *pp) : Command(pp) {}
 inline Kleo::ImportCertificatesCommand::ImportCertificatesCommand(QAbstractItemView *v, Private *pp) : Command(v, pp) {}
 
-#endif /* __KLEOPATRA_IMPORTCERTIFICATESCOMMAND_P_H__ */
 
