@@ -35,7 +35,7 @@ class SetInitialPinCommand::Private : public CardCommand::Private
     }
 public:
     explicit Private(SetInitialPinCommand *qq, const std::string &serialNumber);
-    ~Private();
+    ~Private() override;
 
 private:
     void init()
@@ -48,7 +48,7 @@ private:
             return;
         }
 
-        SetInitialPinDialog *dlg = new SetInitialPinDialog;
+        auto dlg = new SetInitialPinDialog;
         applyWindowID(dlg);
         dlg->setAttribute(Qt::WA_DeleteOnClose);
         dlg->setWindowTitle(i18nc("@title:window", "Set Initial Pin"));
