@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef __KLEOPATRA_CONFIG_CRYPTOOPERATIONSCONFIGWIDGET_H__
-#define __KLEOPATRA_CONFIG_CRYPTOOPERATIONSCONFIGWIDGET_H__
+#pragma once
 
 #include <QWidget>
 
@@ -29,7 +28,7 @@ class CryptoOperationsConfigWidget : public QWidget
     Q_OBJECT
 public:
     explicit CryptoOperationsConfigWidget(QWidget *parent = nullptr, Qt::WindowFlags f = {});
-    ~CryptoOperationsConfigWidget();
+    ~CryptoOperationsConfigWidget() override;
 
 public Q_SLOTS:
     void load();
@@ -43,12 +42,15 @@ private:
     void setupGui();
     void setupProfileGui(QBoxLayout *layout);
     void applyProfile(const QString &profile);
+
+private:
     QCheckBox *mQuickEncryptCB,
               *mQuickSignCB,
               *mPGPFileExtCB,
               *mAutoDecryptVerifyCB,
               *mASCIIArmorCB,
-              *mTmpDirCB;
+              *mTmpDirCB,
+              *mSymmetricOnlyCB;
     QComboBox *mChecksumDefinitionCB,
               *mArchiveDefinitionCB;
     QPushButton *mApplyBtn;
@@ -57,4 +59,3 @@ private:
 }
 }
 
-#endif // __KLEOPATRA_CONFIG_CRYPTOOPERATIONSCONFIGWIDGET_H__
