@@ -8,11 +8,12 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_CONF_GROUPSCONFIGPAGE_H__
-#define __KLEOPATRA_CONF_GROUPSCONFIGPAGE_H__
+#pragma once
 
 #include <QWidget>
 
+#include <memory>
+
 class GroupsConfigPage : public QWidget
 {
     Q_OBJECT
@@ -32,4 +33,3 @@ private:
     const std::unique_ptr<Private> d;
 };
 
-#endif // __KLEOPATRA_CONF_GROUPSCONFIGPAGE_H__
