@@ -8,14 +8,13 @@
     SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef __KLEOPATRA_CONF_KLEOPAGECONFIGDIALOG_H__
-#define __KLEOPATRA_CONF_KLEOPAGECONFIGDIALOG_H__
+#pragma once
 
 #include <KPageDialog>
 #include <QList>
 
-class KCModule;
 class KPageWidgetItem;
+class KCModule;
 
 /**
  * KPageDialog based config dialog to be used when
@@ -26,7 +25,7 @@ class KleoPageConfigDialog : public KPageDialog
 public:
     explicit KleoPageConfigDialog(QWidget *parent = nullptr);
 
-    void addModule(const QString &module);
+    void addModule(const QString &name, const QString &docPath, const QString &icon, KCModule *module);
 
 Q_SIGNALS:
     void configCommitted();
@@ -49,4 +48,3 @@ private:
     QMap<QString, QString> mHelpUrls;
 };
 
-#endif /* __KLEOPATRA_CONF_KLEOPAGECONFIGDIALOG_H__ */
