@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_CRYPTO_GUI_RESULTPAGE_H__
-#define __KLEOPATRA_CRYPTO_GUI_RESULTPAGE_H__
+#pragma once
 
 #include <crypto/gui/wizardpage.h>
 #include <crypto/task.h>
@@ -56,4 +55,3 @@ private:
 }
 }
 
-#endif // __KLEOPATRA_CRYPTO_GUI_RESULTPAGE_H__
