@@ -12,8 +12,8 @@
 #include <QVector>
 #include <gpgme++/key.h>
 
-class QGridLayout;
 class QCheckBox;
+class QVBoxLayout;
 
 namespace Kleo
 {
@@ -31,6 +31,13 @@ public:
      * done only either as sign or as encrypt */
     explicit SignEncryptWidget(QWidget *parent = nullptr, bool cmsSigEncExclusive = false);
 
+    /** Overwrite default text with custom text, e.g. with a character marked
+     *  as shortcut key. */
+    void setSignAsText(const QString &text);
+    void setEncryptForMeText(const QString &text);
+    void setEncryptForOthersText(const QString &text);
+    void setEncryptWithPasswordText(const QString &text);
+
     /** Returns the list of recipients selected in the dialog
      * or an empty list if encryption is disabled */
     std::vector<GpgME::Key> recipients() const;
@@ -109,6 +116,8 @@ Q_SIGNALS:
 
 private:
     CertificateLineEdit* addRecipientWidget();
+    void onProtocolChanged();
+    void updateCheckBoxes();
 
 private:
     KeySelectionCombo *mSigSelect = nullptr;
@@ -117,15 +126,14 @@ private:
     QVector<UnknownRecipientWidget *> mUnknownWidgets;
     QVector<GpgME::Key> mAddedKeys;
     QVector<KeyGroup> mAddedGroups;
-    QGridLayout *mRecpLayout = nullptr;
+    QVBoxLayout *mRecpLayout = nullptr;
     QString mOp;
     AbstractKeyListModel *mModel = nullptr;
     QCheckBox *mSymmetric = nullptr;
     QCheckBox *mSigChk = nullptr;
     QCheckBox *mEncOtherChk = nullptr;
     QCheckBox *mEncSelfChk = nullptr;
-    int mRecpRowCount = 2;
-    GpgME::Protocol mCurrentProto;
+    GpgME::Protocol mCurrentProto = GpgME::UnknownProtocol;
     const bool mIsExclusive;
 };
 } // namespace Kleo
