@@ -15,8 +15,8 @@
 
 #include <utils/pimpl_ptr.h>
 
+#include <KMime/HeaderParsing>
 #include <gpgme++/global.h>
-#include <kmime/kmime_header_parsing.h>
 
 #include <memory>
 #include <vector>
