@@ -405,7 +405,7 @@ static QStringList find_base_directories(const QStringList &files)
     bool changed;
     do {
         changed = false;
-        std::set<QDir, less_dir>::iterator it = dirs.begin();
+        auto it = dirs.begin();
         while (it != dirs.end()) {
             QDir dir = *it;
             if (dir.cdUp() && dirs.count(dir)) {
@@ -486,7 +486,7 @@ static std::vector<SumFile> find_sums_by_input_files(const QStringList &files, Q
     std::vector<SumFile> sumfiles;
     sumfiles.reserve(dirs2sums.size());
 
-    for (std::map<QDir, std::set<QString, less_file>, less_dir>::const_iterator it = dirs2sums.begin(), end = dirs2sums.end(); it != end; ++it) {
+    for (auto it = dirs2sums.begin(), end = dirs2sums.end(); it != end; ++it) {
 
         if (it->second.empty()) {
             continue;
@@ -494,7 +494,7 @@ static std::vector<SumFile> find_sums_by_input_files(const QStringList &files, Q
 
         const QDir &dir = it->first;
 
-        Q_FOREACH (const QString &sumFileName, it->second) {
+        for (const QString &sumFileName : std::as_const(it->second)) {
 
             const std::vector<File> summedfiles = parse_sum_file(dir.absoluteFilePath(sumFileName));
             QStringList files;
@@ -657,7 +657,7 @@ void VerifyChecksumsController::Private::run()
             const quint64 factor = total / std::numeric_limits<int>::max() + 1;
 
             quint64 done = 0;
-            Q_FOREACH (const SumFile &sumFile, sumfiles) {
+            for (const SumFile &sumFile : sumfiles) {
                 Q_EMIT progress(done / factor, total / factor,
                                 i18n("Verifying checksums (%2) in %1", sumFile.checksumDefinition->label(), sumFile.dir.path()));
                 bool fatal = false;
