@@ -4,8 +4,10 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
+#include <config-kleopatra.h>
+
 #include "certificatedetailswidget.h"
-#include "ui_certificatedetailswidget.h"
+
 #include "kleopatra_debug.h"
 #include "exportdialog.h"
 #include "trustchainwidget.h"
@@ -26,6 +28,9 @@
 #include <Libkleo/Formatting>
 #include <Libkleo/Dn>
 #include <Libkleo/KeyCache>
+#include <Libkleo/GnuPG>
+
+#include <KLocalizedString>
 
 #include <gpgme++/context.h>
 #include <gpgme++/key.h>
@@ -36,11 +41,18 @@
 #include <QGpgME/KeyListJob>
 
 #include <QDateTime>
-#include <QDialogButtonBox>
-#include <QMenu>
-#include <KConfigGroup>
-#include <KSharedConfig>
+#include <QGridLayout>
+#include <QGroupBox>
+#include <QHBoxLayout>
+#include <QLabel>
 #include <QLocale>
+#include <QMenu>
+#include <QPushButton>
+#include <QSpacerItem>
+#include <QToolButton>
+#include <QTreeWidget>
+
+#include <set>
 
 #include <gpgme++/gpgmepp_version.h>
 #if GPGMEPP_VERSION >= 0x10E00 // 1.14.0
@@ -55,6 +67,10 @@
     ui.row->setVisible(false); \
     ui.row##Lbl->setVisible(false);
 
+#define SHOW_ROW(row) \
+    ui.row->setVisible(true); \
+    ui.row##Lbl->setVisible(true);
+
 Q_DECLARE_METATYPE(GpgME::UserID)
 
 using namespace Kleo;
@@ -62,9 +78,7 @@ using namespace Kleo;
 class CertificateDetailsWidget::Private
 {
 public:
-    Private(CertificateDetailsWidget *parent)
-        : updateInProgress (false), q(parent)
-    {}
+    Private(CertificateDetailsWidget *qq);
 
     void setupCommonProperties();
     void setupPGPProperties();
@@ -93,13 +107,285 @@ public:
                      const std::vector<GpgME::Key> &, const QString &,
                      const GpgME::Error &);
 
-    Ui::CertificateDetailsWidget ui;
-    GpgME::Key key;
-    bool updateInProgress;
 private:
     CertificateDetailsWidget *const q;
+
+public:
+    GpgME::Key key;
+    bool updateInProgress = false;
+
+private:
+    struct UI {
+        QGridLayout *gridLayout_2;
+        QHBoxLayout *hboxLayout_1;
+        QPushButton *addUserIDBtn;
+        QPushButton *changePassphraseBtn;
+        QPushButton *trustChainDetailsBtn;
+        QPushButton *genRevokeBtn;
+        QPushButton *certifyBtn;
+        QGroupBox *groupBox;
+        QGridLayout *gridLayout;
+        QLabel *validFromLbl;
+        QLabel *validFrom;
+        QSpacerItem *horizontalSpacer_3;
+        QLabel *expiresLbl;
+        QHBoxLayout *horizontalLayout_3;
+        QLabel *expires;
+        QToolButton *changeExpirationBtn;
+        QLabel *typeLbl;
+        QLabel *type;
+        QLabel *fingerprintLbl;
+        QLabel *fingerprint;
+        QLabel *publishingLbl;
+        QPushButton *publishing;
+        QLabel *smimeIssuerLbl;
+        QLabel *smimeIssuer;
+        QLabel *compliance;
+        QLabel *complianceLbl;
+        QLabel *trustedIntroducerLbl;
+        QLabel *trustedIntroducer;
+        QHBoxLayout *horizontalLayout;
+        QPushButton *moreDetailsBtn;
+        QPushButton *exportBtn;
+        QPushButton *webOfTrustBtn;
+        QSpacerItem *horizontalSpacer;
+        QTreeWidget *userIDTable;
+        QLabel *label;
+        QLabel *smimeOwnerLbl;
+        QLabel *smimeRelatedAddresses;
+        QLabel *smimeOwner;
+
+        void setupUi(QWidget *parent)
+        {
+            gridLayout_2 = new QGridLayout(parent);
+            gridLayout_2->setContentsMargins(0, 0, 0, 0);
+            hboxLayout_1 = new QHBoxLayout();
+            addUserIDBtn = new QPushButton(i18n("Add email address"), parent);
+
+            hboxLayout_1->addWidget(addUserIDBtn);
+
+            changePassphraseBtn = new QPushButton(i18n("Change passphrase"), parent);
+
+            hboxLayout_1->addWidget(changePassphraseBtn);
+
+            trustChainDetailsBtn = new QPushButton(i18n("Trust chain details..."), parent);
+
+            hboxLayout_1->addWidget(trustChainDetailsBtn);
+
+            genRevokeBtn = new QPushButton(i18n("Generate revocation certificate"), parent);
+            genRevokeBtn->setToolTip(u"<html>" +
+                                     i18n("A revocation certificate is a file that serves as a \"kill switch\" to publicly "
+                                          "declare that a key shall not anymore be used.  It is not possible "
+                                          "to retract such a revocation certificate once it has been published.") +
+                                     u"</html>");
+
+            hboxLayout_1->addWidget(genRevokeBtn);
+
+            certifyBtn = new QPushButton(i18n("Certify"), parent);
+
+            hboxLayout_1->addWidget(certifyBtn);
+
+            gridLayout_2->addLayout(hboxLayout_1, 4, 0, 1, 3);
+
+            groupBox = new QGroupBox(i18n("Certificate Details"), parent);
+            groupBox->setFlat(false);
+            gridLayout = new QGridLayout(groupBox);
+            int row = 0;
+            validFromLbl = new QLabel(i18n("Valid from:"), groupBox);
+
+            gridLayout->addWidget(validFromLbl, row, 0, 1, 1);
+
+            validFrom = new QLabel(groupBox);
+            validFrom->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);
+
+            gridLayout->addWidget(validFrom, row, 1, 1, 1);
+
+            horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
+
+            gridLayout->addItem(horizontalSpacer_3, row, 2, 1, 1);
+            row++;
+
+            expiresLbl = new QLabel(i18n("Expires:"), groupBox);
+
+            gridLayout->addWidget(expiresLbl, row, 0, 1, 1);
+
+            horizontalLayout_3 = new QHBoxLayout();
+            expires = new QLabel(groupBox);
+            expires->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);
+
+            horizontalLayout_3->addWidget(expires);
+
+            changeExpirationBtn = new QToolButton(groupBox);
+            changeExpirationBtn->setToolTip(i18n("Change"));
+            changeExpirationBtn->setIcon(QIcon::fromTheme(QStringLiteral("editor")));
+            changeExpirationBtn->setIconSize(QSize(16, 16));
+            changeExpirationBtn->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
+
+            horizontalLayout_3->addWidget(changeExpirationBtn);
+
+            gridLayout->addLayout(horizontalLayout_3, row, 1, 1, 1);
+            row++;
+
+            typeLbl = new QLabel(i18n("Type:"), groupBox);
+
+            gridLayout->addWidget(typeLbl, row, 0, 1, 1);
+
+            type = new QLabel(groupBox);
+            type->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);
+
+            gridLayout->addWidget(type, row, 1, 1, 1);
+            row++;
+
+            fingerprintLbl = new QLabel(i18n("Fingerprint:"), groupBox);
+
+            gridLayout->addWidget(fingerprintLbl, row, 0, 1, 1);
+
+            fingerprint = new QLabel(groupBox);
+            fingerprint->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);
+
+            gridLayout->addWidget(fingerprint, row, 1, 1, 2);
+            row++;
+
+            publishingLbl = new QLabel(i18n("Publishing:"), groupBox);
+
+            gridLayout->addWidget(publishingLbl, row, 0, 1, 1);
+
+            publishing = new QPushButton(i18n("Publish Certificate"), groupBox);
+
+            gridLayout->addWidget(publishing, row, 1, 1, 1);
+            row++;
+
+            smimeIssuerLbl = new QLabel(i18n("Issuer:"), groupBox);
+
+            gridLayout->addWidget(smimeIssuerLbl, row, 0, 1, 1);
+
+            smimeIssuer = new QLabel(groupBox);
+            smimeIssuer->setWordWrap(true);
+            smimeIssuer->setTextInteractionFlags(Qt::TextBrowserInteraction);
+
+            gridLayout->addWidget(smimeIssuer, row, 1, 1, 2);
+            row++;
+
+            compliance = new QLabel(i18n("Compliance:"), groupBox);
+            compliance->setWordWrap(true);
+            compliance->setTextInteractionFlags(Qt::TextBrowserInteraction);
+
+            gridLayout->addWidget(compliance, row, 0, 1, 1);
+
+            complianceLbl = new QLabel(groupBox);
+            complianceLbl->setWordWrap(true);
+            complianceLbl->setTextInteractionFlags(Qt::TextBrowserInteraction);
+
+            gridLayout->addWidget(complianceLbl, row, 1, 1, 2);
+            row++;
+
+            trustedIntroducerLbl = new QLabel(i18n("Trusted introducer for:"), groupBox);
+            trustedIntroducerLbl->setToolTip(i18n("See certifications for details."));
+            trustedIntroducerLbl->setTextInteractionFlags(Qt::TextBrowserInteraction);
+
+            gridLayout->addWidget(trustedIntroducerLbl, row, 0, 1, 1);
+
+            trustedIntroducer = new QLabel(groupBox);
+            trustedIntroducer->setWordWrap(true);
+            trustedIntroducer->setToolTip(i18n("See certifications for details."));
+            trustedIntroducer->setTextInteractionFlags(Qt::TextBrowserInteraction);
+
+            gridLayout->addWidget(trustedIntroducer, row, 1, 1, 2);
+            row++;
+
+            horizontalLayout = new QHBoxLayout();
+            moreDetailsBtn = new QPushButton(i18n("More details..."), groupBox);
+
+            horizontalLayout->addWidget(moreDetailsBtn);
+
+            exportBtn = new QPushButton(i18n("Export..."), groupBox);
+
+            horizontalLayout->addWidget(exportBtn);
+
+            webOfTrustBtn = new QPushButton(i18n("Certifications..."), groupBox);
+
+            horizontalLayout->addWidget(webOfTrustBtn);
+
+            horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
+
+            horizontalLayout->addItem(horizontalSpacer);
+
+            gridLayout->addLayout(horizontalLayout, row, 0, 1, 3);
+
+            gridLayout_2->addWidget(groupBox, 6, 0, 1, 3);
+
+            userIDTable = new QTreeWidget(parent);
+            QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
+            __qtreewidgetitem->setText(0, QString::fromUtf8("1"));
+            userIDTable->setHeaderItem(__qtreewidgetitem);
+            userIDTable->setEditTriggers(QAbstractItemView::NoEditTriggers);
+            userIDTable->setSelectionMode(QAbstractItemView::SingleSelection);
+            userIDTable->setRootIsDecorated(false);
+            userIDTable->setUniformRowHeights(true);
+            userIDTable->setAllColumnsShowFocus(true);
+
+            gridLayout_2->addWidget(userIDTable, 3, 0, 1, 3);
+
+            label = new QLabel(i18n("You can use this certificate to secure communication with the following email addresses:"), parent);
+            label->setWordWrap(true);
+
+            gridLayout_2->addWidget(label, 0, 0, 1, 3);
+
+            smimeOwnerLbl = new QLabel(i18n("Owner:"), parent);
+
+            gridLayout_2->addWidget(smimeOwnerLbl, 1, 0, 1, 1);
+
+            smimeRelatedAddresses = new QLabel(i18n("Related addresses:"), parent);
+            QFont font;
+            font.setBold(true);
+            font.setWeight(75);
+            smimeRelatedAddresses->setFont(font);
+
+            gridLayout_2->addWidget(smimeRelatedAddresses, 2, 0, 1, 1);
+
+            smimeOwner = new QLabel(parent);
+            smimeOwner->setWordWrap(true);
+            smimeOwner->setTextInteractionFlags(Qt::TextBrowserInteraction);
+
+            gridLayout_2->addWidget(smimeOwner, 1, 1, 1, 2);
+        }
+    } ui;
 };
 
+CertificateDetailsWidget::Private::Private(CertificateDetailsWidget *qq)
+    : q{qq}
+{
+    ui.setupUi(q);
+
+    connect(ui.addUserIDBtn, &QPushButton::clicked,
+            q, [this]() { addUserID(); });
+    connect(ui.changePassphraseBtn, &QPushButton::clicked,
+            q, [this]() { changePassphrase(); });
+    connect(ui.genRevokeBtn, &QPushButton::clicked,
+            q, [this]() { genRevokeCert(); });
+    connect(ui.changeExpirationBtn, &QPushButton::clicked,
+            q, [this]() { changeExpiration(); });
+    connect(ui.smimeOwner, &QLabel::linkActivated,
+            q, [this](const QString &link) { smimeLinkActivated(link); });
+    connect(ui.smimeIssuer, &QLabel::linkActivated,
+            q, [this](const QString &link) { smimeLinkActivated(link); });
+    connect(ui.trustChainDetailsBtn, &QPushButton::pressed,
+            q, [this]() { showTrustChainDialog(); });
+    connect(ui.moreDetailsBtn, &QPushButton::pressed,
+            q, [this]() { showMoreDetails(); });
+    connect(ui.publishing, &QPushButton::pressed,
+            q, [this]() { publishCertificate(); });
+    connect(ui.certifyBtn, &QPushButton::clicked,
+            q, [this]() { certifyClicked(); });
+    connect(ui.webOfTrustBtn, &QPushButton::clicked,
+            q, [this]() { webOfTrustClicked(); });
+    connect(ui.exportBtn, &QPushButton::clicked,
+            q, [this]() { exportClicked(); });
+
+    connect(Kleo::KeyCache::instance().get(), &Kleo::KeyCache::keysMayHaveChanged,
+            q, [this]() { keysMayHaveChanged(); });
+}
+
 void CertificateDetailsWidget::Private::setupCommonProperties()
 {
     // TODO: Enable once implemented
@@ -125,7 +411,7 @@ void CertificateDetailsWidget::Private::setupCommonProperties()
     ui.type->setText(Kleo::Formatting::type(key));
     ui.fingerprint->setText(Formatting::prettyID(key.primaryFingerprint()));
 
-    if (Kleo::Formatting::complianceMode().isEmpty()) {
+    if (!Kleo::gnupgIsDeVsCompliant()) {
         HIDE_ROW(compliance)
     } else {
         ui.complianceLbl->setText(Kleo::Formatting::complianceStringForKey(key));
@@ -343,7 +629,7 @@ void CertificateDetailsWidget::Private::userIDTableContextMenuRequested(const QP
 
     const auto userID = item->data(0, Qt::UserRole).value<GpgME::UserID>();
 
-    QMenu *menu = new QMenu(q);
+    auto menu = new QMenu(q);
     menu->addAction(QIcon::fromTheme(QStringLiteral("view-certificate-sign")),
                     i18n("Certify..."),
                     q, [this, userID]() {
@@ -437,6 +723,44 @@ QString CertificateDetailsWidget::Private::tofuTooltipString(const GpgME::UserID
     return html;
 }
 
+#ifdef GPGMEPP_SUPPORTS_TRUST_SIGNATURES
+namespace
+{
+auto isGood(const GpgME::UserID::Signature &signature)
+{
+    return signature.status() == GpgME::UserID::Signature::NoError &&
+           !signature.isInvalid() &&
+           0x10 <= signature.certClass() && signature.certClass() <= 0x13;
+}
+
+auto accumulateTrustDomains(const std::vector<GpgME::UserID::Signature> &signatures)
+{
+    return std::accumulate(
+        std::begin(signatures), std::end(signatures),
+        std::set<QString>(),
+        [] (auto domains, const auto &signature) {
+            if (isGood(signature) && signature.isTrustSignature()) {
+                domains.insert(Formatting::trustSignatureDomain(signature));
+            }
+            return domains;
+        }
+    );
+}
+
+auto accumulateTrustDomains(const std::vector<GpgME::UserID> &userIds)
+{
+    return std::accumulate(
+        std::begin(userIds), std::end(userIds),
+        std::set<QString>(),
+        [] (auto domains, const auto &userID) {
+            const auto newDomains = accumulateTrustDomains(userID.signatures());
+            std::copy(std::begin(newDomains), std::end(newDomains), std::inserter(domains, std::end(domains)));
+            return domains;
+        }
+    );
+}
+}
+#endif
 
 void CertificateDetailsWidget::Private::setupPGPProperties()
 {
@@ -448,6 +772,18 @@ void CertificateDetailsWidget::Private::setupPGPProperties()
     ui.userIDTable->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(ui.userIDTable, &QAbstractItemView::customContextMenuRequested,
             q, [this](const QPoint &p) { userIDTableContextMenuRequested(p); });
+
+#ifdef GPGMEPP_SUPPORTS_TRUST_SIGNATURES
+    const auto trustDomains = accumulateTrustDomains(key.userIDs());
+    if (trustDomains.empty()) {
+        HIDE_ROW(trustedIntroducer)
+    } else {
+        SHOW_ROW(trustedIntroducer)
+        ui.trustedIntroducer->setText(QStringList(std::begin(trustDomains), std::end(trustDomains)).join(u", "));
+    }
+#else
+    HIDE_ROW(trustedIntroducer)
+#endif
 }
 
 static QString formatDNToolTip(const Kleo::DN &dn)
@@ -477,6 +813,7 @@ static QString formatDNToolTip(const Kleo::DN &dn)
 void CertificateDetailsWidget::Private::setupSMIMEProperties()
 {
     HIDE_ROW(publishing)
+    HIDE_ROW(trustedIntroducer)
 
     const auto ownerId = key.userID(0);
     const Kleo::DN dn(ownerId.id());
@@ -524,56 +861,26 @@ void CertificateDetailsWidget::Private::smimeLinkActivated(const QString &link)
 }
 
 CertificateDetailsWidget::CertificateDetailsWidget(QWidget *parent)
-    : QWidget(parent)
-    , d(new Private(this))
-{
-    d->ui.setupUi(this);
-
-    connect(d->ui.addUserIDBtn, &QPushButton::clicked,
-            this, [this]() { d->addUserID(); });
-    connect(d->ui.changePassphraseBtn, &QPushButton::clicked,
-            this, [this]() { d->changePassphrase(); });
-    connect(d->ui.genRevokeBtn, &QPushButton::clicked,
-            this, [this]() { d->genRevokeCert(); });
-    connect(d->ui.changeExpirationBtn, &QPushButton::clicked,
-            this, [this]() { d->changeExpiration(); });
-    connect(d->ui.smimeOwner, &QLabel::linkActivated,
-            this, [this](const QString &link) { d->smimeLinkActivated(link); });
-    connect(d->ui.smimeIssuer, &QLabel::linkActivated,
-            this, [this](const QString &link) { d->smimeLinkActivated(link); });
-    connect(d->ui.trustChainDetailsBtn, &QPushButton::pressed,
-            this, [this]() { d->showTrustChainDialog(); });
-    connect(d->ui.moreDetailsBtn, &QPushButton::pressed,
-            this, [this]() { d->showMoreDetails(); });
-    connect(d->ui.publishing, &QPushButton::pressed,
-            this, [this]() { d->publishCertificate(); });
-    connect(d->ui.certifyBtn, &QPushButton::clicked,
-            this, [this]() { d->certifyClicked(); });
-    connect(d->ui.webOfTrustBtn, &QPushButton::clicked,
-            this, [this]() { d->webOfTrustClicked(); });
-    connect(d->ui.exportBtn, &QPushButton::clicked,
-            this, [this]() { d->exportClicked(); });
-
-    connect(Kleo::KeyCache::instance().get(), &Kleo::KeyCache::keysMayHaveChanged,
-            this, [this]() { d->keysMayHaveChanged(); });
-}
-
-CertificateDetailsWidget::~CertificateDetailsWidget()
+    : QWidget{parent}
+    , d{std::make_unique<Private>(this)}
 {
 }
 
+CertificateDetailsWidget::~CertificateDetailsWidget() = default;
+
 void CertificateDetailsWidget::Private::keyListDone(const GpgME::KeyListResult &,
                                                     const std::vector<GpgME::Key> &keys,
                                                     const QString &,
-                                                    const GpgME::Error &) {
-        updateInProgress = false;
-        if (keys.size() != 1) {
-            qCWarning(KLEOPATRA_LOG) << "Invalid keylist result in update.";
-            return;
-        }
-        // As we listen for keysmayhavechanged we get the update
-        // after updating the keycache.
-        KeyCache::mutableInstance()->insert(keys);
+                                                    const GpgME::Error &)
+{
+    updateInProgress = false;
+    if (keys.size() != 1) {
+        qCWarning(KLEOPATRA_LOG) << "Invalid keylist result in update.";
+        return;
+    }
+    // As we listen for keysmayhavechanged we get the update
+    // after updating the keycache.
+    KeyCache::mutableInstance()->insert(keys);
 }
 
 void CertificateDetailsWidget::Private::setUpdatedKey(const GpgME::Key &k)
@@ -626,53 +933,4 @@ GpgME::Key CertificateDetailsWidget::key() const
     return d->key;
 }
 
-CertificateDetailsDialog::CertificateDetailsDialog(QWidget *parent)
-    : QDialog(parent)
-{
-    setWindowTitle(i18nc("@title:window", "Certificate Details"));
-    auto l = new QVBoxLayout(this);
-    l->addWidget(new CertificateDetailsWidget(this));
-
-    auto bbox = new QDialogButtonBox(this);
-    auto btn = bbox->addButton(QDialogButtonBox::Close);
-    connect(btn, &QPushButton::pressed, this, &QDialog::accept);
-    l->addWidget(bbox);
-    readConfig();
-}
-
-CertificateDetailsDialog::~CertificateDetailsDialog()
-{
-    writeConfig();
-}
-
-void CertificateDetailsDialog::readConfig()
-{
-    KConfigGroup dialog(KSharedConfig::openConfig(), "CertificateDetailsDialog");
-    const QSize size = dialog.readEntry("Size", QSize(730, 280));
-    if (size.isValid()) {
-        resize(size);
-    }
-}
-
-void CertificateDetailsDialog::writeConfig()
-{
-    KConfigGroup dialog(KSharedConfig::openConfig(), "CertificateDetailsDialog");
-    dialog.writeEntry("Size", size());
-    dialog.sync();
-}
-
-void CertificateDetailsDialog::setKey(const GpgME::Key &key)
-{
-    auto w = findChild<CertificateDetailsWidget*>();
-    Q_ASSERT(w);
-    w->setKey(key);
-}
-
-GpgME::Key CertificateDetailsDialog::key() const
-{
-    auto w = findChild<CertificateDetailsWidget*>();
-    Q_ASSERT(w);
-    return w->key();
-}
-
 #include "moc_certificatedetailswidget.cpp"
