@@ -6,11 +6,12 @@
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef DIALOGS_PIVCARDAPPLICATIONADMINISTRATIONKEYINPUTDIALOG_H
-#define DIALOGS_PIVCARDAPPLICATIONADMINISTRATIONKEYINPUTDIALOG_H
+#pragma once
 
 #include <QDialog>
 
+#include <memory>
+
 namespace Kleo
 {
 namespace Dialogs
@@ -36,4 +37,3 @@ private:
 } // namespace Kleo
 
 
-#endif // DIALOGS_PIVCARDAPPLICATIONADMINISTRATIONKEYINPUTDIALOG_H
