@@ -66,7 +66,7 @@ void SubKeysWidget::Private::tableContextMenuRequested(const QPoint &p)
     }
     const auto subkey = item->data(0, Qt::UserRole).value<GpgME::Subkey>();
 
-    QMenu *menu = new QMenu(q);
+    auto menu = new QMenu(q);
     connect(menu, &QMenu::aboutToHide, menu, &QObject::deleteLater);
 
     bool hasActions = false;
@@ -77,10 +77,7 @@ void SubKeysWidget::Private::tableContextMenuRequested(const QPoint &p)
         menu->addAction(i18n("Change Expiry Date..."), q,
                 [this, subkey]() {
                     auto cmd = new ChangeExpiryCommand(subkey.parent());
-                    if (subkey.keyID() != key.keyID()) {
-                        // do not set the primary key as subkey
-                        cmd->setSubkey(subkey);
-                    }
+                    cmd->setSubkey(subkey);
                     ui.subkeysTree->setEnabled(false);
                     connect(cmd, &ChangeExpiryCommand::finished,
                             q, [this]() {
@@ -226,7 +223,7 @@ SubKeysDialog::~SubKeysDialog()
 
 void SubKeysDialog::readConfig()
 {
-    KConfigGroup dialog(KSharedConfig::openConfig(), "SubKeysDialog");
+    KConfigGroup dialog(KSharedConfig::openStateConfig(), "SubKeysDialog");
     const QSize size = dialog.readEntry("Size", QSize(820, 280));
     if (size.isValid()) {
         resize(size);
@@ -235,7 +232,7 @@ void SubKeysDialog::readConfig()
 
 void SubKeysDialog::writeConfig()
 {
-    KConfigGroup dialog(KSharedConfig::openConfig(), "SubKeysDialog");
+    KConfigGroup dialog(KSharedConfig::openStateConfig(), "SubKeysDialog");
     dialog.writeEntry("Size", size());
     dialog.sync();
 }
