@@ -8,6 +8,7 @@
 */
 #include "updatenotification.h"
 
+#include <Libkleo/Compat>
 #include <Libkleo/GnuPG>
 
 #include "kleopatra_debug.h"
@@ -44,9 +45,7 @@ namespace
 static void gpgconf_set_update_check(bool value)
 {
     auto conf = QGpgME::cryptoConfig();
-    auto entry = conf->entry(QStringLiteral("dirmngr"),
-                             QStringLiteral("Enforcement"),
-                             QStringLiteral("allow-version-check"));
+    auto entry = getCryptoConfigEntry(conf, "dirmngr", "allow-version-check");
     if (!entry) {
         qCDebug(KLEOPATRA_LOG) << "allow-version-check entry not found";
         return;
@@ -113,7 +112,7 @@ void UpdateNotification::checkUpdate(QWidget *parent, bool force)
         updatecfg.writeEntry("AllowVersionCheckSetOnce", true);
     }
 
-    const auto current = gpg4winVersion();
+    const auto current = gpg4winVersionNumber();
     GpgME::Error err;
     const auto lastshown = updatecfg.readEntry("LastShown", QDateTime());
 
@@ -158,8 +157,8 @@ void UpdateNotification::checkUpdate(QWidget *parent, bool force)
         }
     }
 #else
-    Q_UNUSED(parent);
-    Q_UNUSED(force);
+    Q_UNUSED(parent)
+    Q_UNUSED(force)
 #endif
 }
 
