@@ -3,8 +3,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef KLEO_WEBOFTRUSTDIALOG_H
-#define KLEO_WEBOFTRUSTDIALOG_H
+#pragma once
 
 #include <QWidget>
 #include <QDialog>
@@ -22,7 +21,7 @@ class WebOfTrustDialog : public QDialog
 
 public:
     explicit WebOfTrustDialog(QWidget *parent = nullptr);
-    ~WebOfTrustDialog();
+    ~WebOfTrustDialog() override;
 
     void setKey(const GpgME::Key &key);
     GpgME::Key key() const;
@@ -32,4 +31,3 @@ private:
 };
 
 } // namespace Kleo
-#endif
