@@ -11,28 +11,26 @@
 
 #include "commands/certifycertificatecommand.h"
 #include "commands/revokecertificationcommand.h"
-
-#include <QHeaderView>
-#include <QVBoxLayout>
-#include <QTreeView>
-
-#include <gpgme++/key.h>
-#include <gpgme++/keylistresult.h>
-
-#include <QGpgME/Protocol>
-#include <QGpgME/KeyListJob>
+#include "utils/tags.h"
 
 #include <Libkleo/KeyCache>
 #include <Libkleo/UserIDListModel>
 
-#include "kleopatra_debug.h"
-#include "commands/command.h"
-#include "utils/tags.h"
-
-#include <KMessageBox>
 #include <KLocalizedString>
+#include <KMessageBox>
 
+#include <QHeaderView>
 #include <QMenu>
+#include <QTreeView>
+#include <QVBoxLayout>
+
+#include <QGpgME/KeyListJob>
+#include <QGpgME/Protocol>
+
+#include <gpgme++/key.h>
+#include <gpgme++/keylistresult.h>
+
+#include "kleopatra_debug.h"
 
 using namespace Kleo;
 
@@ -49,7 +47,7 @@ private:
 
 public:
     Private(WebOfTrustWidget *qq)
-        : q(qq)
+        : q{qq}
     {
         certificationsModel.enableRemarks(Tags::tagsEnabled());
 
@@ -57,6 +55,9 @@ public:
         certificationsTV->setModel(&certificationsModel);
         certificationsTV->setAllColumnsShowFocus(true);
         certificationsTV->setSelectionMode(QAbstractItemView::ExtendedSelection);
+        if (!Tags::tagsEnabled()) {
+            certificationsTV->hideColumn(static_cast<int>(UserIDListModel::Column::Tags));
+        }
 
         auto vLay = new QVBoxLayout(q);
         vLay->setContentsMargins(0, 0, 0, 0);
@@ -181,7 +182,7 @@ public:
             return;
         }
 
-        QMenu *menu = new QMenu(q);
+        auto menu = new QMenu(q);
         if (!userID.isNull()) {
             addActionsForUserID(menu, userID);
         }
@@ -222,12 +223,14 @@ public:
 };
 
 
-WebOfTrustWidget::WebOfTrustWidget(QWidget *parent) :
-    QWidget(parent),
-    d(new Private(this))
+WebOfTrustWidget::WebOfTrustWidget(QWidget *parent)
+    : QWidget{parent}
+    , d{std::make_unique<Private>(this)}
 {
 }
 
+WebOfTrustWidget::~WebOfTrustWidget() = default;
+
 GpgME::Key WebOfTrustWidget::key() const
 {
     return d->key;
@@ -236,7 +239,7 @@ GpgME::Key WebOfTrustWidget::key() const
 void WebOfTrustWidget::setKey(const GpgME::Key &key)
 {
     if (key.protocol() != GpgME::OpenPGP) {
-        qCDebug(KLEOPATRA_LOG) << "Trust chain is only supported for CMS keys";
+        qCDebug(KLEOPATRA_LOG) << "List of Certifications is only supported for OpenPGP keys";
         return;
     }
 
@@ -247,10 +250,6 @@ void WebOfTrustWidget::setKey(const GpgME::Key &key)
     d->startSignatureListing();
 }
 
-WebOfTrustWidget::~WebOfTrustWidget()
-{
-}
-
 void WebOfTrustWidget::signatureListingNextKey(const GpgME::Key &key)
 {
     GpgME::Key merged = key;
