@@ -59,6 +59,11 @@
 #include <memory>
 #include <KSharedConfig>
 
+
+#ifdef Q_OS_WIN
+#include <QtPlatformHeaders/QWindowsWindowFunctions>
+#endif
+
 using namespace Kleo;
 using namespace Kleo::Commands;
 
@@ -110,14 +115,24 @@ public:
 private:
     void connectConfigureDialog()
     {
-        if (configureDialog && q->mainWindow()) {
-            connect(configureDialog, SIGNAL(configCommitted()), q->mainWindow(), SLOT(slotConfigCommitted()));
+        if (configureDialog) {
+            if (q->mainWindow()) {
+                connect(configureDialog, SIGNAL(configCommitted()),
+                        q->mainWindow(), SLOT(slotConfigCommitted()));
+            }
+            connect(configureDialog, &ConfigureDialog::configCommitted,
+                    q, &KleopatraApplication::configurationChanged);
         }
     }
     void disconnectConfigureDialog()
     {
-        if (configureDialog && q->mainWindow()) {
-            disconnect(configureDialog, SIGNAL(configCommitted()), q->mainWindow(), SLOT(slotConfigCommitted()));
+        if (configureDialog) {
+            if (q->mainWindow()) {
+                disconnect(configureDialog, SIGNAL(configCommitted()),
+                           q->mainWindow(), SLOT(slotConfigCommitted()));
+            }
+            disconnect(configureDialog, &ConfigureDialog::configCommitted,
+                       q, &KleopatraApplication::configurationChanged);
         }
     }
 
@@ -191,6 +206,10 @@ KleopatraApplication::KleopatraApplication(int &argc, char *argv[])
 
 void KleopatraApplication::init()
 {
+#ifdef Q_OS_WIN
+    QWindowsWindowFunctions::setWindowActivationBehavior(
+            QWindowsWindowFunctions::AlwaysActivateWindow);
+#endif
     d->init();
     add_resources();
     d->setupKeyCache();
