@@ -10,8 +10,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRAAPPLICATION_H__
-#define __KLEOPATRAAPPLICATION_H__
+#pragma once
 
 #include <QApplication>
 #include <QCommandLineParser>
@@ -33,7 +32,7 @@ public:
      * call is done and our init / call might be forwarded to
      * another instance. */
     KleopatraApplication(int &argc, char *argv[]);
-    ~KleopatraApplication();
+    ~KleopatraApplication() override;
 
     /** Initialize the application. Without calling init any
      * other call to KleopatraApplication will result in undefined behavior
@@ -96,9 +95,10 @@ Q_SIGNALS:
      * correct exitValue */
     void setExitValue(int value);
 
+    void configurationChanged();
+
 private:
     class Private;
     kdtools::pimpl_ptr<Private> d;
 };
 
-#endif // __KLEOPATRAAPPLICATION_H__
