@@ -7,8 +7,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef __LIBKLEOPATRACLIENT_CORE_SELECTCERTIFICATECOMMAND_H__
-#define __LIBKLEOPATRACLIENT_CORE_SELECTCERTIFICATECOMMAND_H__
+#pragma once
 
 #include <libkleopatraclient/core/command.h>
 
@@ -20,7 +19,7 @@ class KLEOPATRACLIENTCORE_EXPORT SelectCertificateCommand : public Command
     Q_OBJECT
 public:
     explicit SelectCertificateCommand(QObject *parent = nullptr);
-    ~SelectCertificateCommand();
+    ~SelectCertificateCommand() override;
 
     // Inputs
 
@@ -54,4 +53,3 @@ public:
 
 }
 
-#endif /* __LIBKLEOPATRACLIENT_CORE_SELECTCERTIFICATECOMMAND_H__ */
