@@ -18,7 +18,7 @@ class DeviceInfoWatcher : public QObject
     Q_OBJECT
 public:
     explicit DeviceInfoWatcher(QObject *parent = nullptr);
-    ~DeviceInfoWatcher();
+    ~DeviceInfoWatcher() override;
 
     static bool isSupported();
 
