@@ -6,13 +6,10 @@
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef SMARTCARD_PIVCARD_H
-#define SMARTCARD_PIVCARD_H
+#pragma once
 
 #include "card.h"
 
-#include <QMap>
-
 namespace Kleo
 {
 namespace SmartCard
@@ -39,20 +36,12 @@ public:
     static QString keyDisplayName(const std::string &keyRef);
     static std::vector< std::pair<std::string, QString> > supportedAlgorithms(const std::string &keyRef);
 
-    void setCardInfo(const std::vector< std::pair<std::string, std::string> > &infos);
-
     std::string keyAlgorithm(const std::string &keyRef) const;
     void setKeyAlgorithm(const std::string &keyRef, const std::string &algorithm);
 
     std::string certificateData(const std::string &keyRef) const;
     void setCertificateData(const std::string &keyRef, const std::string &data);
-
-    bool operator == (const Card& other) const override;
-
-private:
-    QMap <std::string, std::string> mMetaInfo;
 };
 } // namespace Smartcard
 } // namespace Kleopatra
 
-#endif // SMARTCARD_PIVCARD_H
