@@ -22,12 +22,10 @@
 #ifdef GPGME_SUPPORTS_API_FOR_DEVICEINFOWATCHER
 # include "deviceinfowatcher.h"
 #endif
-#include "keypairinfo.h"
 
+#include <Libkleo/Assuan>
 #include <Libkleo/GnuPG>
-
 #include <Libkleo/FileSystemWatcher>
-#include <Libkleo/Stl_Util>
 
 #ifdef QGPGME_HAS_DEBUG
 # include <QGpgME/Debug>
@@ -35,28 +33,21 @@
 
 #include <gpgme++/context.h>
 #include <gpgme++/defaultassuantransaction.h>
-#include <gpgme++/key.h>
+#include <gpgme++/engineinfo.h>
 
 #include <gpg-error.h>
 
 #include "openpgpcard.h"
 #include "netkeycard.h"
 #include "pivcard.h"
+#include "p15card.h"
 
-#include <QStringList>
 #include <QMutex>
 #include <QWaitCondition>
 #include <QThread>
 #include <QPointer>
 #include <QRegularExpression>
 
-#include <set>
-#include <list>
-#include <algorithm>
-#include <iterator>
-#include <utility>
-#include <cstdlib>
-
 #include "utils/kdtoolsglobal.h"
 
 #include "kleopatra_debug.h"
@@ -114,7 +105,7 @@ static QDebug operator<<(QDebug s, const GpgME::Error &err)
 
 static QDebug operator<<(QDebug s, const std::vector< std::pair<std::string, std::string> > &v)
 {
-    typedef std::pair<std::string, std::string> pair;
+    using pair = std::pair<std::string, std::string>;
     s << '(';
     for (const pair &p : v) {
         s << "status(" << QString::fromStdString(p.first) << ") =" << QString::fromStdString(p.second) << '\n';
@@ -165,73 +156,11 @@ static Card::PinState parse_pin_state(const QString &s)
     }
 }
 
-template<typename T>
-static std::unique_ptr<T> gpgagent_transact(std::shared_ptr<Context> &gpgAgent, const char *command, std::unique_ptr<T> transaction, Error &err)
-{
-    qCDebug(KLEOPATRA_LOG) << "gpgagent_transact(" << command << ")";
-    err = gpgAgent->assuanTransact(command, std::move(transaction));
-    if (err.code()) {
-        qCDebug(KLEOPATRA_LOG) << "gpgagent_transact(" << command << "): Error:" << err;
-        if (err.code() >= GPG_ERR_ASS_GENERAL && err.code() <= GPG_ERR_ASS_UNKNOWN_INQUIRE) {
-            qCDebug(KLEOPATRA_LOG) << "Assuan problem, killing context";
-            gpgAgent.reset();
-        }
-        return std::unique_ptr<T>();
-    }
-    std::unique_ptr<AssuanTransaction> t = gpgAgent->takeLastAssuanTransaction();
-    return std::unique_ptr<T>(dynamic_cast<T*>(t.release()));
-}
-
-static std::unique_ptr<DefaultAssuanTransaction> gpgagent_default_transact(std::shared_ptr<Context> &gpgAgent, const char *command, Error &err)
-{
-    return gpgagent_transact(gpgAgent, command, std::unique_ptr<DefaultAssuanTransaction>(new DefaultAssuanTransaction), err);
-}
-
-static const std::string gpgagent_data(std::shared_ptr<Context> gpgAgent, const char *command, Error &err)
-{
-    const std::unique_ptr<DefaultAssuanTransaction> t = gpgagent_default_transact(gpgAgent, command, err);
-    if (t.get()) {
-        qCDebug(KLEOPATRA_LOG) << "gpgagent_data(" << command << "): got" << QString::fromStdString(t->data());
-        return t->data();
-    } else {
-        qCDebug(KLEOPATRA_LOG) << "gpgagent_data(" << command << "): t == NULL";
-        return std::string();
-    }
-}
-
-static const std::vector< std::pair<std::string, std::string> > gpgagent_statuslines(std::shared_ptr<Context> gpgAgent, const char *what, Error &err)
-{
-    const std::unique_ptr<DefaultAssuanTransaction> t = gpgagent_default_transact(gpgAgent, what, err);
-    if (t.get()) {
-        qCDebug(KLEOPATRA_LOG) << "agent_getattr_status(" << what << "): got" << t->statusLines();
-        return t->statusLines();
-    } else {
-        qCDebug(KLEOPATRA_LOG) << "agent_getattr_status(" << what << "): t == NULL";
-        return std::vector<std::pair<std::string, std::string> >();
-    }
-}
-
-static const std::string gpgagent_status(const std::shared_ptr<Context> &gpgAgent, const char *what, Error &err)
-{
-    const auto lines = gpgagent_statuslines (gpgAgent, what, err);
-    // The status is only the last attribute
-    // e.g. for SCD SERIALNO it would only be "SERIALNO" and for SCD GETATTR FOO
-    // it would only be FOO
-    const char *p = strrchr(what, ' ');
-    const char *needle = (p + 1) ? (p + 1) : what;
-    for (const auto &pair: lines) {
-        if (pair.first == needle) {
-            return pair.second;
-        }
-    }
-    return std::string();
-}
-
 static const std::string scd_getattr_status(std::shared_ptr<Context> &gpgAgent, const char *what, Error &err)
 {
     std::string cmd = "SCD GETATTR ";
     cmd += what;
-    return gpgagent_status(gpgAgent, cmd.c_str(), err);
+    return Assuan::sendStatusCommand(gpgAgent, cmd.c_str(), err);
 }
 
 static const std::string getAttribute(std::shared_ptr<Context> &gpgAgent, const char *attribute, const char *versionHint)
@@ -254,7 +183,7 @@ static std::vector<CardApp> getCardsAndApps(std::shared_ptr<Context> &gpgAgent,
     std::vector<CardApp> result;
     if (gpgHasMultiCardMultiAppSupport()) {
         const std::string command = "SCD GETINFO all_active_apps";
-        const auto statusLines = gpgagent_statuslines(gpgAgent, command.c_str(), err);
+        const auto statusLines = Assuan::sendStatusLinesCommand(gpgAgent, command.c_str(), err);
         if (err) {
             return result;
         }
@@ -279,7 +208,7 @@ static std::vector<CardApp> getCardsAndApps(std::shared_ptr<Context> &gpgAgent,
         }
     } else {
         // use SCD SERIALNO to get the currently active card
-        const auto serialNumber = gpgagent_status(gpgAgent, "SCD SERIALNO", err);
+        const auto serialNumber = Assuan::sendStatusCommand(gpgAgent, "SCD SERIALNO", err);
         if (err) {
             return result;
         }
@@ -298,7 +227,7 @@ static std::vector<CardApp> getCardsAndApps(std::shared_ptr<Context> &gpgAgent,
 static std::string switchCard(std::shared_ptr<Context> &gpgAgent, const std::string &serialNumber, Error &err)
 {
     const std::string command = "SCD SWITCHCARD " + serialNumber;
-    const auto statusLines = gpgagent_statuslines(gpgAgent, command.c_str(), err);
+    const auto statusLines = Assuan::sendStatusLinesCommand(gpgAgent, command.c_str(), err);
     if (err) {
         return std::string();
     }
@@ -314,7 +243,7 @@ static std::string switchApp(std::shared_ptr<Context> &gpgAgent, const std::stri
                              const std::string &appName, Error &err)
 {
     const std::string command = "SCD SWITCHAPP " + appName;
-    const auto statusLines = gpgagent_statuslines(gpgAgent, command.c_str(), err);
+    const auto statusLines = Assuan::sendStatusLinesCommand(gpgAgent, command.c_str(), err);
     if (err) {
         return std::string();
     }
@@ -364,30 +293,6 @@ static const char * get_openpgp_card_manufacturer_from_serial_number(const std::
     }
 }
 
-static const std::string get_manufacturer(std::shared_ptr<Context> &gpgAgent, Error &err)
-{
-    // The result of SCD GETATTR MANUFACTURER is the manufacturer ID as unsigned number
-    // optionally followed by the name of the manufacturer, e.g.
-    // 6 Yubico
-    // 65534 unmanaged S/N range
-    const auto manufacturerIdAndName = scd_getattr_status(gpgAgent, "MANUFACTURER", err);
-    if (err.code()) {
-        if (err.code() == GPG_ERR_INV_NAME) {
-            qCDebug(KLEOPATRA_LOG) << "get_manufacturer(): Querying for attribute MANUFACTURER not yet supported; needs GnuPG 2.2.21+";
-        } else {
-            qCWarning(KLEOPATRA_LOG) << "Running SCD GETATTR MANUFACTURER failed:" << err;
-        }
-        return std::string();
-    }
-    const auto startOfManufacturerName = manufacturerIdAndName.find(' ');
-    if (startOfManufacturerName == std::string::npos) {
-        // only ID without manufacturer name
-        return "unknown";
-    }
-    const auto manufacturerName = manufacturerIdAndName.substr(startOfManufacturerName + 1);
-    return manufacturerName;
-}
-
 static bool isOpenPGPCardSerialNumber(const std::string &serialNumber)
 {
     return serialNumber.size() == 32 && serialNumber.substr(0, 12) == "D27600012401";
@@ -426,19 +331,18 @@ static void handle_openpgp_card(std::shared_ptr<Card> &ci, std::shared_ptr<Conte
     Error err;
     auto pgpCard = new OpenPGPCard(*ci);
 
-    pgpCard->setManufacturer(get_manufacturer(gpg_agent, err));
-    if (err.code()) {
-        // fallback, e.g. if gpg does not yet support querying for the MANUFACTURER attribute
-        pgpCard->setManufacturer(get_openpgp_card_manufacturer_from_serial_number(ci->serialNumber()));
-    }
-
-    const auto info = gpgagent_statuslines(gpg_agent, "SCD LEARN --force", err);
+    const auto info = Assuan::sendStatusLinesCommand(gpg_agent, "SCD LEARN --force", err);
     if (err.code()) {
         ci->setStatus(Card::CardError);
         return;
     }
     pgpCard->setCardInfo(info);
 
+    if (pgpCard->manufacturer().empty()) {
+        // fallback in case MANUFACTURER is not yet included in the card info
+        pgpCard->setManufacturer(get_openpgp_card_manufacturer_from_serial_number(ci->serialNumber()));
+    }
+
     setDisplaySerialNumber(pgpCard, gpg_agent);
 
     ci.reset(pgpCard);
@@ -448,7 +352,7 @@ static void readKeyPairInfoFromPIVCard(const std::string &keyRef, PIVCard *pivCa
 {
     Error err;
     const std::string command = std::string("SCD READKEY --info-only -- ") + keyRef;
-    const auto keyPairInfoLines = gpgagent_statuslines(gpg_agent, command.c_str(), err);
+    const auto keyPairInfoLines = Assuan::sendStatusLinesCommand(gpg_agent, command.c_str(), err);
     if (err) {
         qCWarning(KLEOPATRA_LOG) << "Running" << command << "failed:" << err;
         return;
@@ -472,7 +376,7 @@ static void readCertificateFromPIVCard(const std::string &keyRef, PIVCard *pivCa
 {
     Error err;
     const std::string command = std::string("SCD READCERT ") + keyRef;
-    const std::string certificateData = gpgagent_data(gpg_agent, command.c_str(), err);
+    const std::string certificateData = Assuan::sendDataCommand(gpg_agent, command.c_str(), err);
     if (err && err.code() != GPG_ERR_NOT_FOUND) {
         qCWarning(KLEOPATRA_LOG) << "Running" << command << "failed:" << err;
         return;
@@ -490,7 +394,7 @@ static void handle_piv_card(std::shared_ptr<Card> &ci, std::shared_ptr<Context>
     Error err;
     auto pivCard = new PIVCard(*ci);
 
-    const auto info = gpgagent_statuslines(gpg_agent, "SCD LEARN --force", err);
+    const auto info = Assuan::sendStatusLinesCommand(gpg_agent, "SCD LEARN --force", err);
     if (err) {
         ci->setStatus(Card::CardError);
         return;
@@ -509,6 +413,32 @@ static void handle_piv_card(std::shared_ptr<Card> &ci, std::shared_ptr<Context>
     ci.reset(pivCard);
 }
 
+static void handle_p15_card(std::shared_ptr<Card> &ci, std::shared_ptr<Context> &gpg_agent)
+{
+    Error err;
+    auto p15Card = new P15Card(*ci);
+
+    auto info = Assuan::sendStatusLinesCommand(gpg_agent, "SCD LEARN --force", err);
+    if (err) {
+        ci->setStatus(Card::CardError);
+        return;
+    }
+    const auto fprs = Assuan::sendStatusLinesCommand(gpg_agent, "SCD GETATTR KEY-FPR", err);
+    if (!err) {
+        info.insert(info.end(), fprs.begin(), fprs.end());
+    }
+
+    /* Create the key stubs */
+    Assuan::sendStatusLinesCommand(gpg_agent, "READKEY --card --no-data -- $SIGNKEYID", err);
+    Assuan::sendStatusLinesCommand(gpg_agent, "READKEY --card --no-data -- $ENCRKEYID", err);
+
+    p15Card->setCardInfo(info);
+
+    setDisplaySerialNumber(p15Card, gpg_agent);
+
+    ci.reset(p15Card);
+}
+
 static void handle_netkey_card(std::shared_ptr<Card> &ci, std::shared_ptr<Context> &gpg_agent)
 {
     Error err;
@@ -558,7 +488,7 @@ static void handle_netkey_card(std::shared_ptr<Card> &ci, std::shared_ptr<Contex
     }
     nkCard->setPinStates(states);
 
-    const auto info = gpgagent_statuslines(gpg_agent, "SCD LEARN --force", err);
+    const auto info = Assuan::sendStatusLinesCommand(gpg_agent, "SCD LEARN --force", err);
     if (err) {
         ci->setStatus(Card::CardError);
         return;
@@ -624,12 +554,17 @@ static std::shared_ptr<Card> get_card_status(const std::string &serialNumber, co
         return ci;
     } else if (appName == OpenPGPCard::AppName) {
         qCDebug(KLEOPATRA_LOG) << "get_card_status: found OpenPGP card" << ci->serialNumber().c_str() << "end";
+        ci->setAuthenticationKeyRef(OpenPGPCard::pgpAuthKeyRef());
         handle_openpgp_card(ci, gpg_agent);
         return ci;
     } else if (appName == PIVCard::AppName) {
         qCDebug(KLEOPATRA_LOG) << "get_card_status: found PIV card" << ci->serialNumber().c_str() << "end";
         handle_piv_card(ci, gpg_agent);
         return ci;
+    } else if (appName == P15Card::AppName) {
+        qCDebug(KLEOPATRA_LOG) << "get_card_status: found P15 card" << ci->serialNumber().c_str() << "end";
+        handle_p15_card(ci, gpg_agent);
+        return ci;
     } else {
         qCDebug(KLEOPATRA_LOG) << "get_card_status: unhandled application:" << appName;
         return ci;
@@ -654,7 +589,7 @@ static std::vector<std::shared_ptr<Card> > update_cardinfo(std::shared_ptr<Conte
     {
         Error err;
         const char *command = (gpgHasMultiCardMultiAppSupport()) ? "SCD SERIALNO --all" : "SCD SERIALNO";
-        const std::string serialno = gpgagent_status(gpgAgent, command, err);
+        const std::string serialno = Assuan::sendStatusCommand(gpgAgent, command, err);
         if (err) {
             if (isCardNotPresentError(err)) {
                 qCDebug(KLEOPATRA_LOG) << "update_cardinfo: No card present";
@@ -774,7 +709,7 @@ private Q_SLOTS:
         std::list<Transaction> ft;
         KDAB_SYNCHRONIZED(m_mutex)
         ft.splice(ft.begin(), m_finishedTransactions);
-        for (const Transaction &t : qAsConst(ft))
+        for (const Transaction &t : std::as_const(ft))
             if (t.receiver && t.slot && *t.slot) {
                 QMetaObject::invokeMethod(t.receiver, t.slot, Qt::DirectConnection, Q_ARG(GpgME::Error, err));
             }
@@ -888,9 +823,9 @@ private:
                 }
                 if (!err) {
                     if (assuanTransaction) {
-                        (void)gpgagent_transact(gpgAgent, command.constData(), std::unique_ptr<AssuanTransaction>(assuanTransaction), err);
+                        (void)Assuan::sendCommand(gpgAgent, command.constData(), std::unique_ptr<AssuanTransaction>(assuanTransaction), err);
                     } else {
-                        (void)gpgagent_default_transact(gpgAgent, command.constData(), err);
+                        (void)Assuan::sendCommand(gpgAgent, command.constData(), err);
                     }
                 }
 
@@ -956,7 +891,7 @@ public:
             connect(&watcher, &FileSystemWatcher::triggered, this, &::ReaderStatusThread::ping);
         }
     }
-    ~Private()
+    ~Private() override
     {
         stop();
         if (!wait(100)) {
