@@ -126,7 +126,7 @@ DragQueen::~DragQueen()
 
 void DragQueen::setUrl(const QString &url)
 {
-    QMimeData *data = new QMimeData;
+    auto data = new QMimeData;
     QList<QUrl> urls;
     urls.push_back(QUrl(url));
     data->setUrls(urls);
@@ -184,19 +184,12 @@ void DragQueen::mouseMoveEvent(QMouseEvent *e)
     if (m_data &&
             (e->buttons() & Qt::LeftButton) &&
             (m_dragStartPosition - e->pos()).manhattanLength() > QApplication::startDragDistance()) {
-        QDrag *drag = new QDrag(this);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        if (const QPixmap *const pix = pixmap()) {
-            drag->setPixmap(*pix);
-            drag->setHotSpot(calculate_hot_spot(e->pos(), pix->size(), this));
-        }
-#else
+        auto drag = new QDrag(this);
         const QPixmap pix = pixmap(Qt::ReturnByValue);
         if (!pix.isNull()) {
             drag->setPixmap(pix);
             drag->setHotSpot(calculate_hot_spot(e->pos(), pix.size(), this));
         }
-#endif
         drag->setMimeData(new MimeDataProxy(m_data));
         drag->exec();
     } else {
