@@ -54,7 +54,7 @@ class Page : public Kleo::KeyTreeView
 public:
     Page(const QString &title, const QString &id, const QString &text, AbstractKeyListSortFilterProxyModel *proxy = nullptr, const QString &toolTip = QString(), QWidget *parent = nullptr, const KConfigGroup &group = KConfigGroup());
     Page(const KConfigGroup &group, QWidget *parent = nullptr);
-    ~Page();
+    ~Page() override;
 
     void setTemporary(bool temporary);
     bool isTemporary() const
@@ -691,6 +691,11 @@ void TabWidget::Private::setCornerAction(QAction *action, Qt::Corner corner)
     tabWidget.setCornerWidget(b, corner);
 }
 
+QString TabWidget::stringFilter() const
+{
+    return d->currentPage() ? d->currentPage()->stringFilter() : QString{};
+}
+
 void TabWidget::setStringFilter(const QString &filter)
 {
     if (Page *const page = d->currentPage()) {
@@ -919,7 +924,8 @@ void TabWidget::saveViews(KConfig *config) const
     if (!config) {
         return;
     }
-    Q_FOREACH (const QString &group, extractViewGroups(config)) {
+    const auto extraView{extractViewGroups(config)};
+    for (const QString &group : extraView) {
         config->deleteGroup(group);
     }
     unsigned int vg = 0;
